pub struct ContainerImageMetadata {
pub entity_id: Option<WorkloadmetaEntityId>,
pub entity_meta: Option<EntityMeta>,
pub repo_tags: Vec<String>,
pub repo_digests: Vec<String>,
pub media_type: String,
pub size_bytes: i64,
pub os: String,
pub os_version: String,
pub architecture: String,
pub variant: String,
pub layers: Vec<ContainerImageLayer>,
pub sbom: Option<CompressedSbom>,
}Fields
entity_id: Option<WorkloadmetaEntityId>entity_meta: Option<EntityMeta>repo_digests: Vec<String>media_type: Stringsize_bytes: i64os: Stringos_version: Stringarchitecture: Stringvariant: Stringlayers: Vec<ContainerImageLayer>sbom: Option<CompressedSbom>Trait Implementations
Sourceimpl Clone for ContainerImageMetadata
impl Clone for ContainerImageMetadata
Sourcefn clone(&self) -> ContainerImageMetadata
fn clone(&self) -> ContainerImageMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContainerImageMetadata
impl Debug for ContainerImageMetadata
Sourceimpl Default for ContainerImageMetadata
impl Default for ContainerImageMetadata
Sourceimpl Message for ContainerImageMetadata
impl Message for ContainerImageMetadata
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ContainerImageMetadata
impl PartialEq for ContainerImageMetadata
Sourcefn eq(&self, other: &ContainerImageMetadata) -> bool
fn eq(&self, other: &ContainerImageMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ContainerImageMetadata