pub struct RemoteAgentClient<T> { /* private fields */ }Expand description
RemoteAgent is the service exposed by the Core Agent for remote agents to manage their lifecycle (registration and refresh) and to report operational events back to the Core Agent.
Implementations
Sourceimpl<T> RemoteAgentClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> RemoteAgentClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> RemoteAgentClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn register_remote_agent(
&mut self,
request: impl IntoRequest<RegisterRemoteAgentRequest>,
) -> Result<Response<RegisterRemoteAgentResponse>, Status>
pub async fn register_remote_agent( &mut self, request: impl IntoRequest<RegisterRemoteAgentRequest>, ) -> Result<Response<RegisterRemoteAgentResponse>, Status>
Registers a remote agent.
Sourcepub async fn refresh_remote_agent(
&mut self,
request: impl IntoRequest<RefreshRemoteAgentRequest>,
) -> Result<Response<RefreshRemoteAgentResponse>, Status>
pub async fn refresh_remote_agent( &mut self, request: impl IntoRequest<RefreshRemoteAgentRequest>, ) -> Result<Response<RefreshRemoteAgentResponse>, Status>
Refreshes a remote agent session.
Sourcepub async fn report_remote_agent_event(
&mut self,
request: impl IntoRequest<ReportRemoteAgentEventRequest>,
) -> Result<Response<ReportRemoteAgentEventResponse>, Status>
pub async fn report_remote_agent_event( &mut self, request: impl IntoRequest<ReportRemoteAgentEventRequest>, ) -> Result<Response<ReportRemoteAgentEventResponse>, Status>
Reports one or more operational events from a remote agent.